@@ -11,9 +11,9 @@ from r3sponse import r3sponse
 
 # source.
 ALIAS = "netw0rk"
-SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=3)
-OS = syst3m.defaults.check_operating_system(supported=["osx", "linux"])
-syst3m.defaults.check_alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
+OS = syst3m.defaults.operating_system(supported=["osx", "linux"])
+syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
 OWNER = os.environ.get("USER")
